package MT::Plugin::LightBox;
use strict;
use MT;
use MT::Plugin;

our $VERSION = '1.1';

use base qw( MT::Plugin );

@MT::Plugin::LightBox::ISA = qw( MT::Plugin );

my $plugin = new MT::Plugin::LightBox ( {
    name => 'LightBox',
    id   => 'LightBox',
    key  => 'lightbox',
    description => '<MT_TRANS phrase=\'_PLUGIN_DESCRIPTION\'>',
    author_name => 'Junnama Noda',
    author_link => 'http://junnama.alfasado.net/online/',
    version     => $VERSION,
    settings => new MT::PluginSettings ( [
        ['lb_classname', { Default => 'lightbox' }],
    ] ),
    l10n_class => 'LightBox::L10N',
} );

MT->add_plugin( $plugin );

sub init_registry {
    my $plugin = shift;
    $plugin->registry( {
        callbacks => {
            'MT::App::CMS::template_param.asset_options_image'
                => \&_asset_options_image_param,
            'MT::App::CMS::template_param.asset_insert'
                => \&_asset_insert_param,
        },
   } );
}

sub _asset_options_image_param {
    my ( $cb, $app, $param, $tmpl ) = @_;
    my $pointer_field = $tmpl->getElementById( 'link_to_popup' );
    my $nodeset = $tmpl->createElement('app:setting', { id => 'link_to_lightbox', 
    label => $plugin->translate( 'Use LightBox' ) ,
    label_class => 'no-header',
    required => 0 });
    my $innerHTML =<<MTML;
        <input type="checkbox" 
        onclick="if(this.checked){document.getElementById('create_thumbnail').checked=true;
        document.getElementById('thumb_width').focus();
        }else{
        document.getElementById('create_thumbnail').checked=false;}"
        name="lightbox" id="lightbox" value="1" <mt:if name="make_thumb">checked="checked" </mt:if>/>
        <label for="lightbox"><__trans_section component="LightBox"><__trans phrase="Use LightBox"></__trans_section></label>
        (<label for="thumb_width"><__trans phrase="width:"></label>
        <input name="lightbox_width" id="lightbox_width" value="" size="4" /> <__trans phrase="pixels">)
MTML
    $nodeset->innerHTML( $innerHTML );
    $tmpl->insertBefore( $nodeset, $pointer_field );
}

sub _asset_insert_param {
    my ( $cb, $app, $param, $tmpl ) = @_;
    if ( $app->param( 'lightbox' ) ) {
        my $lb_classname = $plugin->get_config_value( 'lb_classname' );
        my $upload_html = $param->{ upload_html };
        $upload_html =~ s/<a/<a rel="$lb_classname"/i;
        if ( $app->param( 'lightbox_width' ) ) {
            my $asset_id = $1 if ( $upload_html =~ /<form.*?mt:asset\-id="([0-9]{1,})".*?>/ );
            if ( $asset_id ) {
                require MT::Asset::Image;
                my $asset = MT::Asset::Image->load( $asset_id );
                my %param = ( Width => $app->param( 'lightbox_width' ) );
                my ( $thumbnail, $w, $h ) = $asset->thumbnail_file( %param );
                my $site_path = _site_path( $app->blog );
                my $site_url  = _site_url( $app->blog );
                my $regex_path = quotemeta( $site_path );
                $thumbnail =~ s/^$regex_path/$site_url/;
                $upload_html =~ s/href=".*?"/href="$thumbnail"/i;
            }
        }
        $param->{ upload_html } = $upload_html;
    }
}

sub _site_path {
    my $blog = shift;
    my $site_path = $blog->archive_path;
    $site_path = $blog->site_path unless $site_path;
    if ( $site_path =~ /(.*)\/$/ ) {
        $site_path = $1;
    }
    if ( $^O eq 'MSWin32' ) {
        $site_path =~ s!/!\\!g;
        if ( $site_path =~ /(.*)\\$/ ) {
            $site_path = $1;
        }
    }
    return $site_path;
}

sub _site_url {
    my $blog = shift;
    my $site_url = $blog->site_url;
    if ( $site_url =~ /(.*)\/$/ ) {
        $site_url = $1;
    }
    return $site_url;
}

1;